@@ -7,13 +7,16 @@ use strict;
 
 package Log::Report::Exception;
 use vars '$VERSION';
-$VERSION = '0.24';
+$VERSION = '0.25';
 
 
 use Log::Report 'log-report';
 use POSIX  qw/locale_h/;
 
 
+use overload '""' => 'toString';
+
+
 sub new($@)
 {   my ($class, %args) = @_;
     $args{report_opts} ||= {};
@@ -38,4 +41,10 @@ sub throw(@)
     report $opts, $reason, $self->message;
 }
 
+
+sub toString()
+{   my $self = shift;
+    $self->reason . ": " . $self->message . "\n";
+}
+
 1;
